@@ -6,6 +6,7 @@
 
 
 #' @importFrom dplyr bind_rows
+#' @importFrom rlang as_function
 #' @rdname ggdist-ggproto
 #' @format NULL
 #' @usage NULL
@@ -73,7 +74,7 @@ AbstractStatSlabinterval = ggproto("AbstractStatSlabinterval", AbstractStat,
 
   # Compute the function that defines the slab. That takes a data frame of
   # aesthetic values and a vector of function inputs and returns a data frame
-  # with columns `.input` (from the `input` vector) and `.value` (the result of
+  # with columns `.input` (from the `input` vector) and `f` (the result of
   # applying the function to each value of input).
   # @param data The data frame of aesthetic values
   # @param input Input values for the function (may be ignored in some cases
@@ -107,6 +108,9 @@ AbstractStatSlabinterval = ggproto("AbstractStatSlabinterval", AbstractStat,
   },
 
   compute_panel = function(self, data, scales,
+    limits = self$default_params$limits,
+    n = self$default_params$n,
+    point_interval = self$default_params$point_interval,
     orientation = self$default_params$orientation,
     show_slab = self$default_params$show_slab,
     show_point = self$default_params$show_point,
@@ -122,31 +126,140 @@ AbstractStatSlabinterval = ggproto("AbstractStatSlabinterval", AbstractStat,
     # figure out coordinate transformation
     trans = scales[[x]]$trans %||% scales::identity_trans()
 
-    # SLABS
-    s_data = if (show_slab) {
-      compute_panel_slabs(self, data, scales, trans,
-        orientation = orientation,
-        na.rm = na.rm,
-        ...
-      )
+
+    # SLAB FUNCTION PRE-CALCULATIONS
+    # determine limits of the slab function
+    limits = compute_panel_limits(self, data, scales, trans,
+      orientation = orientation, limits = limits,
+      ...
+    )
+
+    # figure out the points at which values the slab functions should be evaluated
+    # we set up the grid in the transformed space
+    input = trans$inverse(seq(trans$transform(limits[[1]]), trans$transform(limits[[2]]), length.out = n))
+
+
+    # POINT/INTERVAL PRE-CALCULATIONS
+    if (!is.null(point_interval)) {
+      point_interval = if (is.character(point_interval)) {
+        # ensure we always search the ggdist namespace for point_interval
+        # functions in case ggdist is not in the caller's search path
+        get0(point_interval, mode = "function") %||%
+          get(point_interval, mode = "function", envir = getNamespace("ggdist"))
+      } else {
+        as_function(point_interval)
+      }
     }
 
-    # INTERVALS
-    i_data = if (show_interval) {
-      compute_panel_intervals(self, data, scales, trans,
-        orientation = orientation,
+
+    results = summarise_by(data, c("group", y), function(d) {
+      dist = check_one_dist(d$dist)
+
+      # we compute *both* the slab functions and intervals first (even if one
+      # or the other will not be shown), since even if a component is not shown,
+      # its values are still available in the other component
+      #
+      # TODO: currently we skip s_data if ggdist.experimental.slab_data_in_intervals
+      # is FALSE and we aren't showing the slab because otherwise we can get a
+      # bunch of spurious warnings when visualizing only intervals on a dist
+      # where the slab functions can't be reliably computed (see e.g. the
+      # logit dotplot example at the end of vignette("dotsinterval")); eventually
+      # I'd like this to be reliable enough that we can compute it for that
+      # example without warnings and remove this guard.
+      s_data = if (getOption("ggdist.experimental.slab_data_in_intervals", FALSE) || show_slab) {
+        self$compute_slab(d,
+          trans = trans, input = input,
+          orientation = orientation, limits = limits, n = n,
+          na.rm = na.rm,
+          ...
+        )
+      } else {
+        data.frame()
+      }
+      i_data = self$compute_interval(d,
+        trans = trans,
+        orientation = orientation, point_interval = point_interval,
         show_point = show_point,
         na.rm = na.rm,
         ...
       )
-    }
 
-    results = bind_rows(s_data, i_data)
+      # SLABS
+      s_data[[x]] = trans$transform(s_data$.input)
+      s_data$.input = NULL
+      if (nrow(s_data) > 0) s_data$datatype = "slab"
+
+
+      # INTERVALS
+      i_data[[x]] = i_data$.value
+      i_data$.value = NULL
+      i_data[[xmin]] = i_data$.lower
+      i_data$.lower = NULL
+      i_data[[xmax]] = i_data$.upper
+      i_data$.upper = NULL
+
+      i_data$level = fct_rev_(ordered(i_data$.width))
+      if (nrow(i_data) > 0) i_data$datatype = "interval"
+
+      # INTERVAL INFO ADDED TO SLAB COMPONENT
+      if (show_slab) {
+        # fill in relevant data from the interval component
+        # this is expensive, so we only do it if we are actually showing the interval
+
+        # find the smallest interval that contains each x value
+        contains_x = outer(i_data[[xmin]], s_data[[x]], `<=`) & outer(i_data[[xmax]], s_data[[x]], `>=`)
+        # need a fake interval guaranteed to contain all points (for NAs, points out of range...)
+        contains_x = rbind(TRUE, contains_x)
+        width = c(Inf, i_data$.width)
+        smallest_interval = apply(ifelse(contains_x, width, NA), 2, which.min)
+
+        # fill in the .width and level of the smallest interval containing x
+        # (or NA if no such interval)
+        s_data$.width = c(NA_real_, i_data$.width)[smallest_interval]
+        s_data$level = vctrs::vec_c(NA, i_data$level)[smallest_interval]
+      }
+
+
+      # SLAB INFO ADDED TO INTERVAL COMPONENT
+      if (
+        getOption("ggdist.experimental.slab_data_in_intervals", FALSE) &&
+        show_interval && nrow(s_data) - sum(is.na(s_data$pdf) | is.na(s_data$cdf)) >= 2
+      ) {
+        # fill in relevant data from the slab component
+        # this is expensive, so we only do it if we are actually showing the interval
+        pdf_fun = if (distr_is_constant(dist)) {
+          dist_value = distr_quantile(dist)(0.5)
+          function(x) ifelse(x == dist_value, Inf, 0)
+        } else {
+          approxfun(s_data[[x]], s_data$pdf, yleft = 0, yright = 0, ties = max)
+        }
+        i_data$pdf = pdf_fun(i_data[[x]])
+        i_data$pdf_min = pdf_fun(i_data[[xmin]])
+        i_data$pdf_max = pdf_fun(i_data[[xmax]])
+
+        cdf_fun = if (distr_is_constant(dist)) {
+          dist_value = distr_quantile(dist)(0.5)
+          function(x) ifelse(x >= dist_value, 1, 0)
+        } else {
+          approxfun(s_data[[x]], s_data$cdf, yleft = 0, yright = 1, method = "constant", ties = max)
+        }
+        i_data$cdf = cdf_fun(i_data[[x]])
+        i_data$cdf_min = cdf_fun(i_data[[xmin]])
+        i_data$cdf_max = cdf_fun(i_data[[xmax]])
+      }
+
+
+      bind_rows(
+        if (show_slab) s_data,
+        if (show_interval) i_data
+      )
+    })
+
     # must ensure there's an f and a .width aesthetic produced even if we don't draw
     # the slab or the interval, otherwise the default aesthetic mappings can break.
     if (nrow(results) > 0) {
-      results$f = results[["f"]] %||% NA
-      results$.width = results[[".width"]] %||% NA
+      results$f = results[["f"]] %||% NA_real_
+      results$.width = results[[".width"]] %||% NA_real_
     }
     results
   }
@@ -165,17 +278,17 @@ na_ = function(m_, ...) {
   else m_(values, na.rm = TRUE)
 }
 
-
+#' Compute the limits and the input x values for slab functions
 #' @param ... stat parameters
+#' @return length 2 vector giving the limits
 #' @noRd
-compute_panel_slabs = function(
+compute_panel_limits = function(
   self, data, scales, trans,
-  orientation, limits, n,
+  orientation, limits,
   ...
 ) {
   define_orientation_variables(orientation)
 
-  # LIMITS
   # determine limits of the slab function
   # we do this first so we can figure out the overall limits
   # based on the min/max limits over the entire input data
@@ -185,7 +298,7 @@ compute_panel_slabs = function(
   max_limits = limits
   if (is.null(max_limits)) {
     if (is.null(scales[[x]]$limits)) {
-      max_limits = c(NA, NA)
+      max_limits = c(NA_real_, NA_real_)
     } else{
       max_limits = trans$inverse(scales[[x]]$limits)
     }
@@ -194,8 +307,8 @@ compute_panel_slabs = function(
   # data-defined limits we want to obey as minimums
   # (the limits are *at least* these, unless the
   # max_limits are more narrow)
-  min_limits = if (is.null(scales[[x]])) {
-    c(NA, NA)
+  min_limits = if (is.null(scales[[x]]) || scales[[x]]$is_empty()) {
+    c(NA_real_, NA_real_)
   } else {
     trans$inverse(scales[[x]]$dimension())
   }
@@ -217,62 +330,26 @@ compute_panel_slabs = function(
   #default to 0 (min) and 1 (max) for unknown limits
   limits = ifelse(is.na(limits), c(0,1), limits)
 
-
-  # SLABS
-  # now, figure out the points at which values the slab functions should be evaluated
-  # we set up the grid in the transformed space
-  input = trans$inverse(seq(trans$transform(limits[[1]]), trans$transform(limits[[2]]), length.out = n))
-
-  # evaluate the slab function
-  s_data = summarise_by(data, c("group", y), self$compute_slab,
-    trans = trans, input = input,
-    orientation = orientation, limits = limits, n = n,
-    ...
-  )
-
-  names(s_data)[names(s_data) == ".value"] = "f"
-  s_data[[x]] = trans$transform(s_data$.input)
-  s_data$.input = NULL
-
-  if (nrow(s_data) > 0) s_data$datatype = "slab"
-  s_data
+  limits
 }
 
-#' @importFrom rlang as_function
-#' @param ... stat parameters
-#' @noRd
-compute_panel_intervals = function(
-  self, data, scales, trans,
-  orientation, point_interval,
-  ...
-) {
-  define_orientation_variables(orientation)
 
-  if (!is.null(point_interval)) {
-    point_interval = if (is.character(point_interval)) {
-      # ensure we always search the ggdist namespace for point_interval
-      # functions in case ggdist is not in the caller's search path
-      get0(point_interval, mode = "function") %||%
-        get(point_interval, mode = "function", envir = getNamespace("ggdist"))
-    } else {
-      as_function(point_interval)
-    }
+# helpers -----------------------------------------------------------------
+
+check_one_dist = function(dist) {
+  if (length(dist) > 1) {
+    stop0(glue('
+      {length(dist)} distributions in `dist` were associated with the same
+      combination of other aesthetics.
+      - Distributions passed to the `dist` aesthetic must be uniquely associated
+        with a combination of levels of the `group` and some other aesthethics
+        (like x, y, color, fill, etc) so that unique intervals, densities, etc.
+        of those distributions are well defined.
+      - Try checking whether you need to adjust the `group` aesthetic or provide
+        some other aesthetic mapping (like color or fill) to differentiate
+        distributions.
+      '
+    ))
   }
-
-  i_data = summarise_by(data, c("group", y), self$compute_interval,
-    trans = trans,
-    orientation = orientation, point_interval = point_interval,
-    ...
-  )
-
-  i_data[[x]] = i_data$.value
-  i_data$.value = NULL
-  i_data[[xmin]] = i_data$.lower
-  i_data$.lower = NULL
-  i_data[[xmax]] = i_data$.upper
-  i_data$.upper = NULL
-
-  i_data$level = fct_rev_(ordered(i_data$.width))
-  if (nrow(i_data) > 0) i_data$datatype = "interval"
-  i_data
+  dist
 }
