@@ -4,16 +4,57 @@
 ###############################################################################
 
 
-# drawing functions -------------------------------------------------------
+# thickness handling functions -------------------------------------------------------
 
+#' normalize thickness values to between 0 and 1
+#' @noRd
+normalize_thickness = function(x) UseMethod("normalize_thickness")
+
+#' @export
+normalize_thickness.default = function(x) {
+  finite_thickness = x[is.finite(x)]
+  if (length(finite_thickness) > 0) {
+    max_finite_thickness = max(finite_thickness)
+    min_finite_thickness = min(finite_thickness, 0)
+    if (max_finite_thickness > min_finite_thickness) {
+      x = (x - min_finite_thickness) / (max_finite_thickness - min_finite_thickness)
+    }
+  }
+  # infinite values get plotted at the max height (e.g. for point masses)
+  if (length(x) > 0) {
+    x[x == Inf] = 1
+  }
+  x
+}
+
+#' @export
+normalize_thickness.ggdist_thickness = function(x) {
+  # thickness values passed directly into the geom (e.g. by
+  # scale_thickness_shared()) are not normalized again.
+  x = as.double(x)
+  # infinite values get plotted at the max height (e.g. for point masses)
+  if (length(x) > 0) {
+    x[x == Inf] = 1
+  }
+  x
+}
+
+#' @export
+normalize_thickness.data.frame = function(x) {
+  x$thickness = normalize_thickness(x$thickness)
+  x
+}
+
+
+#' rescale the slab data (ymin / ymax) to be within the confines of the bounding box
+#' we do this *again* here (rather than in setup_data) because
+#' position_dodge doesn't work if we only do it up there:
+#' positions (like dodge) might change the heights so they aren't
+#' all the same, and we want to preserve our normalization settings.
+#' so we scale things based on the min height to ensure everything
+#' is the same height
+#' @noRd
 rescale_slab_thickness = function(s_data, orientation, normalize, height, y, ymin, ymax) {
-  # rescale the slab data to be within the confines of the bounding box
-  # we do this *again* here (rather than in setup_data) because
-  # position_dodge doesn't work if we only do it up there:
-  # positions (like dodge) might change the heights so they aren't
-  # all the same, and we want to preserve our normalization settings.
-  # so we scale things based on the min height to ensure everything
-  # is the same height
   min_height = min(s_data[[height]])
 
   # must do this within groups so that `side` can vary by slab
@@ -50,6 +91,9 @@ rescale_slab_thickness = function(s_data, orientation, normalize, height, y, ymi
   })
 }
 
+
+# drawing functions -------------------------------------------------------
+
 draw_slabs = function(self, s_data, panel_params, coord,
   orientation, normalize, fill_type, na.rm,
   ...
@@ -63,9 +107,16 @@ draw_slabs = function(self, s_data, panel_params, coord,
   # avoid giving fill type warnings multiple times
   fill_type = switch_fill_type(fill_type, segments = "segments", gradient = "gradient")
 
+  # handle NAs: NAs in thickness should cause slabs to be broken apart into separate
+  # pieces. We'll do this by creating a column to encode runs of NAs that we can
+  # use in the grouping below.
+  s_data$na_thickness_group = cumsum(is.na(s_data$thickness))
+  # now that we've used them for grouping, we can drop rows with NA values of thickness
+  s_data = s_data[!is.na(s_data$thickness),]
+
   # build groups for the slabs
   # must group within both group and y for the polygon and path drawing functions to work
-  slab_grobs = dlply_(s_data, c("group", y), function(d) {
+  slab_grobs = dlply_(s_data, c("group", "na_thickness_group", y), function(d) {
     d = d[order(d[[x]]),]
 
     slab_grob = if (!is.null(d$fill) && !all(is.na(d$fill))) {
@@ -391,42 +442,6 @@ GeomSlabinterval = ggproto("GeomSlabinterval", AbstractGeom,
 
     data$datatype = data[["datatype"]] %||% self$default_aes[["datatype"]]
 
-    # normalize thickness according to what groups the user wants to scale it within
-    normalize_thickness = function(data) {
-      finite_thickness = data$thickness[is.finite(data$thickness)]
-      if (length(finite_thickness) > 0) {
-        max_finite_thickness = max(finite_thickness)
-        if (max_finite_thickness != 0) {
-          data$thickness = data$thickness / max_finite_thickness
-        }
-      }
-      # infinite values get plotted at the max height (e.g. for point masses)
-      if (length(data$thickness) > 0) {
-        data$thickness[data$thickness == Inf] = 1
-      }
-      data
-    }
-    switch(params$normalize,
-      all = {
-        # normalize so max height across all data is 1
-        # this preserves slabs across groups in slab plots
-        data = normalize_thickness(data)
-      },
-      panels = ,
-      xy = ,
-      groups = {
-        # normalize so height in each group or panel is 1
-        normalization_groups = switch(params$normalize,
-          panels = "PANEL",
-          xy = c("PANEL", y),
-          groups = c("PANEL", y, "group")
-        )
-        data = ddply_(data, normalization_groups, normalize_thickness)
-      },
-      none = {},
-      stop('`normalize` must be "all", "panels", "xy", groups", or "none", not "', params$normalize, '"')
-    )
-
     # figure out the bounding rectangles for each group
     # this is necessary so that the bounding box is correct for
     # positions to work (e.g. position_dodge, etc)
@@ -457,6 +472,40 @@ GeomSlabinterval = ggproto("GeomSlabinterval", AbstractGeom,
   draw_slabs = function(self, ...) draw_slabs(self, ...),
   draw_pointintervals = function(self, ...) draw_pointintervals(self, ...),
 
+  draw_layer = function(self, data, params, layout, coord) {
+    define_orientation_variables(params$orientation)
+
+    # normalize thickness according to what groups the user wants to scale it within
+    # must do this here: not setup_data, so it happens after the thickness scale
+    # has been applied; and not draw_panel, because normalization may be applied
+    # across panels.
+    switch(params$normalize,
+      all = {
+        # normalize so max height across all data is 1
+        # this preserves slabs across groups in slab plots
+        data = normalize_thickness(data)
+      },
+      panels = ,
+      xy = ,
+      groups = {
+        # normalize so height in each group or panel is 1
+        normalization_groups = switch(params$normalize,
+          panels = "PANEL",
+          xy = c("PANEL", y),
+          groups = c("PANEL", y, "group")
+        )
+        data = ddply_(data, normalization_groups, normalize_thickness)
+      },
+      none = {
+        # ensure thickness is a thickness-type vector so it is not normalized again
+        data$thickness = normalize_thickness(as_thickness(data$thickness))
+      },
+      stop('`normalize` must be "all", "panels", "xy", groups", or "none", not "', params$normalize, '"')
+    )
+
+    ggproto_parent(AbstractGeom, self)$draw_layer(data, params, layout, coord)
+  },
+
   draw_panel = function(self, data, panel_params, coord,
       orientation = self$default_params$orientation,
       show_slab = self$default_params$show_slab,
@@ -593,12 +642,25 @@ get_justification = function(justification, side, orientation) {
 
 # gradient helpers --------------------------------------------------------
 
-# groups slab data into contiguous components based on (usually) fill, colour, and alpha aesthetics,
-# interpolating values ymin/ymax values at the cutpoints, then returns the necessary data frame
-# (depending on `side`) that has top, bottom, or both sides to it
+#' groups slab data into contiguous components based on (usually) fill, colour, and alpha aesthetics,
+#' interpolating values ymin/ymax values at the cutpoints, then returns the necessary data frame
+#' (depending on `side`) that has top, bottom, or both sides to it
+#' @param slab_data a data frame containing data for a "slab", which should at
+#' least include `x`, `y`, `thickness`, and either `xmin`/`xmax` or `ymin`/`ymax`,
+#' depending on `orientation`.
+#' @param aesthetics the aesthetics to group the slabs by. Consecutive runs of
+#' equal values of all of these aesthetics are grouped together. At cutpoints
+#' between consecutive runs, the `x`/`ymin`/`ymax` (or `y`/`xmin`/`xmax`,
+#' depending on `orientation`) values are interpolated so that slabs just touch.
+#' @param orientation orientation of the slab
+#' @param side side of the slab
+#' @noRd
 #' @importFrom dplyr lag lead
-group_slab_data_by = function(slab_data, aesthetics = c("fill", "colour", "alpha"),
-  orientation = "horizontal", side = "topright"
+group_slab_data_by = function(
+  slab_data,
+  aesthetics = c("fill", "colour", "alpha"),
+  orientation = "horizontal",
+  side = "topright"
 ) {
   define_orientation_variables(orientation)
 
