@@ -15,36 +15,33 @@ compute_slab_dots = function(
   na.rm,
   ...
 ) {
+  dist = data$dist
+  if (distr_is_missing(dist)) {
+    return(data.frame(.input = NA_real_, f = NA_real_, n = NA_integer_))
+  }
+
   quantiles = quantiles %||% NA
   quantiles_provided = !isTRUE(is.na(quantiles))
   dist_quantiles = if (quantiles_provided) quantiles else 100
   probs = ppoints(dist_quantiles, a = 1/2)
 
-  pmap_dfr_(data, function(dist, ...) {
-    if (is.null(dist) || anyNA(dist)) {
-      return(data.frame(.input = NA, .value = NA))
+  if (distr_is_sample(dist)) {
+    input = distr_get_sample(dist)
+    if (quantiles_provided) {
+      # ppoints() with a = 1/2 corresponds to quantile() with type = 5
+      # and ensures that if quantiles == length(data[[x]]) then input == data[[x]]
+      input = quantile(input, ppoints(quantiles, a = 1/2), type = 5, na.rm = na.rm)
     }
+  } else {
+    quantile_fun = distr_quantile(dist)
+    input = quantile_fun(probs)
+  }
 
-    args = args_from_aes(...)
-
-    if (distr_is_sample(dist, args)) {
-      input = distr_get_sample(dist, args)
-      if (quantiles_provided) {
-        # ppoints() with a = 1/2 corresponds to quantile() with type = 5
-        # and ensures that if quantiles == length(data[[x]]) then input == data[[x]]
-        input = quantile(input, ppoints(quantiles, a = 1/2), type = 5, na.rm = na.rm)
-      }
-    } else {
-      quantile_fun = distr_quantile(dist)
-      input = do.call(quantile_fun, c(list(probs), args))
-    }
-
-    data.frame(
-      .input = input,
-      .value = 1,
-      n = length(input)
-    )
-  })
+  data.frame(
+    .input = input,
+    f = 1,
+    n = length(input)
+  )
 }
 
 
